==> jc-1.4.0.tar.gz: java/net/PortUnreachableException.h <==
// public class java.net.PortUnreachableException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 6d3b95690e730b5f java_net_PortUnreachableException
// @dep_class e1b77f50ab8f37ad java_net_SocketException

// header file dependencies
// @dep_header java_net_SocketException

#include "java/net/SocketException.h"

#ifndef _JC_java_net_PortUnreachableException_H_
#define _JC_java_net_PortUnreachableException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_PortUnreachableException$sub_refs	_jc_java_net_PortUnreachableException$sub_refs;
typedef struct _jc_java_net_PortUnreachableException$sub_nonrefs	_jc_java_net_PortUnreachableException$sub_nonrefs;
typedef struct _jc_java_net_PortUnreachableException$refs	_jc_java_net_PortUnreachableException$refs;
typedef struct _jc_java_net_PortUnreachableException$nonrefs	_jc_java_net_PortUnreachableException$nonrefs;
typedef struct _jc_java_net_PortUnreachableException$object	_jc_java_net_PortUnreachableException$object;

typedef struct _jc_java_net_PortUnreachableException$fields_struct	_jc_java_net_PortUnreachableException$fields_struct;
typedef const struct _jc_java_net_PortUnreachableException$vmethods	_jc_java_net_PortUnreachableException$vmethods;
typedef const struct _jc_java_net_PortUnreachableException$vtable	_jc_java_net_PortUnreachableException$vtable;
typedef const struct _jc_java_net_PortUnreachableException$vtype	_jc_java_net_PortUnreachableException$vtype;

// Class fields structure
struct _jc_java_net_PortUnreachableException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_PortUnreachableException$fields_struct _jc_java_net_PortUnreachableException$class_fields;

// Constructors
extern void _jc_java_net_PortUnreachableException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_PortUnreachableException$object *);
extern void _jc_java_net_PortUnreachableException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_PortUnreachableException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_net_PortUnreachableException$vmethods {
};

// Vtable
struct _jc_java_net_PortUnreachableException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_SocketException$vmethods	java_net_SocketException;
	_jc_java_net_PortUnreachableException$vmethods	java_net_PortUnreachableException;
};

// Vtype
struct _jc_java_net_PortUnreachableException$vtype {
	_jc_type			type;
	_jc_java_net_PortUnreachableException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_PortUnreachableException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_PortUnreachableException$refs {
    _jc_java_net_PortUnreachableException$sub_refs	java_net_PortUnreachableException;
    _jc_java_net_SocketException$sub_refs	java_net_SocketException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_PortUnreachableException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_PortUnreachableException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_SocketException$sub_nonrefs	java_net_SocketException;
    _jc_java_net_PortUnreachableException$sub_nonrefs	java_net_PortUnreachableException;
};

// Object instance structure
struct _jc_java_net_PortUnreachableException$object {
	_jc_java_net_PortUnreachableException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_PortUnreachableException$vtype	*vtype;
	_jc_java_net_PortUnreachableException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_PortUnreachableException$vtype _jc_java_net_PortUnreachableException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_PortUnreachableException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_PortUnreachableException$class_object;

#endif	/* _JC_java_net_PortUnreachableException_H_ */

==> jc-1.4.6.tar.gz: java/net/PortUnreachableException.h <==
// public class java.net.PortUnreachableException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 6d3b95690e730b5f java_net_PortUnreachableException
// @dep_class e1b77f50ab8f37ad java_net_SocketException

// header file dependencies
// @dep_header java_net_SocketException

#include "java/net/SocketException.h"

#ifndef _JC_java_net_PortUnreachableException_H_
#define _JC_java_net_PortUnreachableException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_PortUnreachableException$sub_refs	_jc_java_net_PortUnreachableException$sub_refs;
typedef struct _jc_java_net_PortUnreachableException$sub_nonrefs	_jc_java_net_PortUnreachableException$sub_nonrefs;
typedef struct _jc_java_net_PortUnreachableException$refs	_jc_java_net_PortUnreachableException$refs;
typedef struct _jc_java_net_PortUnreachableException$nonrefs	_jc_java_net_PortUnreachableException$nonrefs;
typedef struct _jc_java_net_PortUnreachableException$object	_jc_java_net_PortUnreachableException$object;

typedef struct _jc_java_net_PortUnreachableException$fields_struct	_jc_java_net_PortUnreachableException$fields_struct;
typedef const struct _jc_java_net_PortUnreachableException$vmethods	_jc_java_net_PortUnreachableException$vmethods;
typedef const struct _jc_java_net_PortUnreachableException$vtable	_jc_java_net_PortUnreachableException$vtable;
typedef const struct _jc_java_net_PortUnreachableException$vtype	_jc_java_net_PortUnreachableException$vtype;

// Class fields structure
struct _jc_java_net_PortUnreachableException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_PortUnreachableException$fields_struct _jc_java_net_PortUnreachableException$class_fields;

// Constructors
extern void _jc_java_net_PortUnreachableException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_PortUnreachableException$object *) _JC_JCNI_ATTR;
extern void _jc_java_net_PortUnreachableException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_PortUnreachableException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_PortUnreachableException$vmethods {
};

// Vtable
struct _jc_java_net_PortUnreachableException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_SocketException$vmethods	java_net_SocketException;
	_jc_java_net_PortUnreachableException$vmethods	java_net_PortUnreachableException;
};

// Vtype
struct _jc_java_net_PortUnreachableException$vtype {
	_jc_type			type;
	_jc_java_net_PortUnreachableException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_PortUnreachableException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_PortUnreachableException$refs {
    _jc_java_net_PortUnreachableException$sub_refs	java_net_PortUnreachableException;
    _jc_java_net_SocketException$sub_refs	java_net_SocketException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_PortUnreachableException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_PortUnreachableException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_SocketException$sub_nonrefs	java_net_SocketException;
    _jc_java_net_PortUnreachableException$sub_nonrefs	java_net_PortUnreachableException;
};

// Object instance structure
struct _jc_java_net_PortUnreachableException$object {
	_jc_java_net_PortUnreachableException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_PortUnreachableException$vtype	*vtype;
	_jc_java_net_PortUnreachableException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_PortUnreachableException$vtype _jc_java_net_PortUnreachableException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_PortUnreachableException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_PortUnreachableException$class_object;

#endif	/* _JC_java_net_PortUnreachableException_H_ */
